@@ -14,6 +14,111 @@ fisher.calc <- function (x, na.rm = FALSE, ...) {
   return(sk)
 }
 
+########################## nortest ###########################################
+
+pearson.test <- function (x, n.classes = ceiling(2 * (n^(2/5))), adjust = TRUE) {
+  DNAME <- deparse(substitute(x))
+  x <- x[complete.cases(x)]
+  n <- length(x)
+  if (adjust) {
+    dfd <- 2
+  }
+  else {
+    dfd <- 0
+  }
+  num <- floor(1 + n.classes * pnorm(x, mean(x), sd(x)))
+  count <- tabulate(num, n.classes)
+  prob <- rep(1/n.classes, n.classes)
+  xpec <- n * prob
+  h <- ((count - xpec)^2)/xpec
+  P <- sum(h)
+  pvalue <- pchisq(P, n.classes - dfd - 1, lower.tail = FALSE)
+  RVAL <- list(statistic = c(P = P), p.value = pvalue, method = "Pearson chi-square normality test", 
+               data.name = DNAME, n.classes = n.classes, df = n.classes - 
+                 1 - dfd)
+  class(RVAL) <- "htest"
+  return(RVAL)
+}
+
+lillie.test <- function (x) {
+  DNAME <- deparse(substitute(x))
+  x <- sort(x[complete.cases(x)])
+  n <- length(x)
+  if (n < 5) 
+    stop("sample size must be greater than 4")
+  p <- pnorm((x - mean(x))/sd(x))
+  Dplus <- max(seq(1:n)/n - p)
+  Dminus <- max(p - (seq(1:n) - 1)/n)
+  K <- max(Dplus, Dminus)
+  if (n <= 100) {
+    Kd <- K
+    nd <- n
+  }
+  else {
+    Kd <- K * ((n/100)^0.49)
+    nd <- 100
+  }
+  pvalue <- exp(-7.01256 * Kd^2 * (nd + 2.78019) + 2.99587 * 
+                  Kd * sqrt(nd + 2.78019) - 0.122119 + 0.974598/sqrt(nd) + 
+                  1.67997/nd)
+  if (pvalue > 0.1) {
+    KK <- (sqrt(n) - 0.01 + 0.85/sqrt(n)) * K
+    if (KK <= 0.302) {
+      pvalue <- 1
+    }
+    else if (KK <= 0.5) {
+      pvalue <- 2.76773 - 19.828315 * KK + 80.709644 * 
+        KK^2 - 138.55152 * KK^3 + 81.218052 * KK^4
+    }
+    else if (KK <= 0.9) {
+      pvalue <- -4.901232 + 40.662806 * KK - 97.490286 * 
+        KK^2 + 94.029866 * KK^3 - 32.355711 * KK^4
+    }
+    else if (KK <= 1.31) {
+      pvalue <- 6.198765 - 19.558097 * KK + 23.186922 * 
+        KK^2 - 12.234627 * KK^3 + 2.423045 * KK^4
+    }
+    else {
+      pvalue <- 0
+    }
+  }
+  RVAL <- list(statistic = c(D = K), p.value = pvalue, method = "Lilliefors (Kolmogorov-Smirnov) normality test", 
+               data.name = DNAME)
+  class(RVAL) <- "htest"
+  return(RVAL)
+}
+
+cvm.test <- function (x) {
+  DNAME <- deparse(substitute(x))
+  x <- sort(x[complete.cases(x)])
+  n <- length(x)
+  if (n < 8) 
+    stop("sample size must be greater than 7")
+  p <- pnorm((x - mean(x))/sd(x))
+  W <- (1/(12 * n) + sum((p - (2 * seq(1:n) - 1)/(2 * n))^2))
+  WW <- (1 + 0.5/n) * W
+  if (WW < 0.0275) {
+    pval <- 1 - exp(-13.953 + 775.5 * WW - 12542.61 * WW^2)
+  }
+  else if (WW < 0.051) {
+    pval <- 1 - exp(-5.903 + 179.546 * WW - 1515.29 * WW^2)
+  }
+  else if (WW < 0.092) {
+    pval <- exp(0.886 - 31.62 * WW + 10.897 * WW^2)
+  }
+  else if (WW < 1.1) {
+    pval <- exp(1.111 - 34.242 * WW + 12.832 * WW^2)
+  }
+  else {
+    warning("p-value is smaller than 7.37e-10, cannot be computed more accurately")
+    pval <- 7.37e-10
+  }
+  RVAL <- list(statistic = c(W = W), p.value = pval, method = "Cramer-von Mises normality test", 
+               data.name = DNAME)
+  class(RVAL) <- "htest"
+  return(RVAL)
+}
+
 ########################## reshape ###########################################
 
 melt.data.frame <- function (data, id.vars, measure.vars, variable_name = "variable", 
