@@ -146,9 +146,12 @@ shinyUI(shinydashboardPlus::dashboardPagePlus(
       #test de Normalidad
       shinydashboard::tabItem(tabName = "normalidad", shinydashboard::tabBox(
         id = "BoxNormal", width = NULL, title =
-          tags$div(
-            class = "multiple-select-var",
-            shiny::selectInput(inputId = "sel.normal", label = NULL, choices =  "")
+          shiny::conditionalPanel(
+            "input.BoxNormal == 'tabNormalPlot'",
+            tags$div(
+              class = "multiple-select-var",
+              shiny::selectInput(inputId = "sel.normal", label = NULL, choices = "")
+            )
           ),
         shiny::tabPanel(
           title = labelInput("plotnormal"), value = "tabNormalPlot",
@@ -158,19 +161,31 @@ shinyUI(shinydashboardPlus::dashboardPagePlus(
           DT::DTOutput('calculo.normal')),
         tabsOptions(heights = c(50, 50, 100), tabs.content = list(
           list(shiny::h4(labelInput("opciones")), shiny::hr(),
-               colourpicker::colourInput(
-                 "col.normal", labelInput("selcolor"),
-                 value = "#00FF22AA", allowTransparent = T)),
+               shiny::conditionalPanel(
+                 "input.BoxNormal == 'tabNormalPlot'",
+                 colourpicker::colourInput(
+                   "col.normal", labelInput("selcolor"),
+                   value = "#00FF22AA", allowTransparent = T)
+               ),
+               shiny::conditionalPanel(
+                 "input.BoxNormal == 'tabNormalCalc'",
+                 selectInput("test.tipo", "Tipo de Test", width = "100%",
+                             list("Pearson" = "pearson", "Lilliefors" = "lillie",
+                                  "Cramer-von Mises" = "cvm")),
+                 sliderInput("test.alfa", "Nivel de Significancia (alfa):", 0.05, 0.95, 0.05, 0.05)
+               )
+          ),
           list(
             shiny::conditionalPanel(
               "input.BoxNormal == 'tabNormalPlot'",
-              codigo.monokai("fieldCodeNormal", height = "25vh")),
+              codigo.monokai("fieldCodeNormal", height = "25vh")
+            ),
             shiny::conditionalPanel(
               "input.BoxNormal == 'tabNormalCalc'",
-              codigo.monokai("fieldCalcNormal", height = "20vh")))
-          ))
-        )
-      ),
+              codigo.monokai("fieldCalcNormal", height = "25vh")
+            ))
+        ))
+      )),
 
       #Dispersión
       shinydashboard::tabItem(
@@ -676,7 +691,7 @@ shinyUI(shinydashboardPlus::dashboardPagePlus(
           icono = shiny::icon("info")
         ),
         infoBoxPROMiDAT(
-          labelInput("version"), "1.2.4", icono = shiny::icon("file-code-o"))
+          labelInput("version"), "1.2.7", icono = shiny::icon("file-code-o"))
       )
     ) #shinydashboard::tabItems
   ) #dashboardBody
